@@ -128,7 +128,7 @@ kid3 (${NEWVER}-0) unstable; urgency=low\n\n  * New upstream release.\n\n\
   sed -i "s/PROJECTVERSION=\"${OLDVER}\"/PROJECTVERSION=\"${NEWVER}\"/" translations/extract-merge.sh
   # kid3.spec is used by f-droid to detect a new version, it should be updated exactly before the release.
   if test "$4" = "--finalize"; then
-    sed -i "s/^Version:        ${OLDVER}$/Version:        ${NEWVER}/" kid3.spec
+    sed -i "s/^\(Version: \+\).*$/\1${NEWVER}/" kid3.spec
     OLDCODE=$(sed -n "s/ \+set(QT_ANDROID_APP_VERSION_CODE \([0-9]\+\))/\1/p" CMakeLists.txt)
     NEWCODE=$[ $OLDCODE + 1 ]
     sed -i "s/\( \+set(QT_ANDROID_APP_VERSION_CODE \)\([0-9]\+\))/\1$NEWCODE)/" CMakeLists.txt
@@ -337,26 +337,24 @@ verify_not_in_srcdir
 target=${*:-libs package}
 
 qt_version=5.15.2
-zlib_version=1.2.8
-zlib_patchlevel=5
+zlib_version=1.2.13
+zlib_patchlevel=1
 libogg_version=1.3.4
 libogg_patchlevel=0.1
 libvorbis_version=1.3.7
 libvorbis_patchlevel=1
 ffmpeg3_version=3.2.14
 ffmpeg3_patchlevel=1~deb9u1
-ffmpeg_version=4.4.1
+ffmpeg_version=5.1.2
 ffmpeg_patchlevel=1
-libflac_version=1.3.3
+libflac_version=1.4.2+ds
 libflac_patchlevel=2
 id3lib_version=3.8.3
-id3lib_patchlevel=16.3
-taglib_version=1.12
-taglib_githash=c4a0855f42c05ad9fab8915f27439c8194b6bb94
-chromaprint_version=1.5.0
+id3lib_patchlevel=17
+taglib_version=1.13
+chromaprint_version=1.5.1
 chromaprint_patchlevel=2
-mp4v2_version=2.0.0
-mp4v2_patchlevel=5
+mp4v2_version=2.1.1
 
 # Try to find the configuration from an existing build.
 if test -z "$COMPILER"; then
@@ -391,8 +389,11 @@ if [[ "$QTPREFIX" =~ /([0-9]+)\.([0-9]+)\.([0-9]+)/ ]]; then
   qt_version=$(printf "%d.%d.%d" ${BASH_REMATCH[1]} ${BASH_REMATCH[2]} ${BASH_REMATCH[3]})
   qt_version_major=${BASH_REMATCH[1]}
 else
-  echo "Could not extract Qt version from $QTPREFIX"
-  exit 1
+  echo "Could not extract Qt version from $QTPREFIX, assuming $qt_version"
+  if [[ "$qt_version" =~ ^([0-9]+)\.([0-9]+)\.([0-9]+)$ ]]; then
+    qt_nr=$(printf "%d%02d%02d" ${BASH_REMATCH[1]} ${BASH_REMATCH[2]} ${BASH_REMATCH[3]})
+    qt_version_major=${BASH_REMATCH[1]}
+  fi
 fi
 
 if test "$qt_nr" -ge 51204; then
@@ -445,7 +446,7 @@ if [[ $target = *"libs"* ]]; then
 if test "$compiler" = "gcc-debug"; then
   export CFLAGS="-fPIC"
   export CXXFLAGS="-fPIC"
-  FLAC_BUILD_OPTION="--enable-debug"
+  FLAC_BUILD_OPTION="--enable-debug=yes"
   ID3LIB_BUILD_OPTION="--enable-debug=minimum"
   AV_BUILD_OPTION="--enable-debug=3 --enable-pic --extra-ldexeflags=-pie"
   CMAKE_BUILD_OPTION="-DCMAKE_BUILD_TYPE=Debug"
@@ -454,12 +455,12 @@ elif test "$compiler" = "gcc-self-contained"; then
   export CXX=$gcc_self_contained_cxx
   export CFLAGS="-O2 -fPIC"
   export CXXFLAGS="-O2 -fPIC"
-  FLAC_BUILD_OPTION="--enable-debug"
+  FLAC_BUILD_OPTION="--enable-debug=info CFLAGS=-O2 CXXFLAGS=-O2"
   ID3LIB_BUILD_OPTION="--enable-debug=minimum"
   AV_BUILD_OPTION="--enable-debug=1 --enable-pic --extra-ldexeflags=-pie"
   CMAKE_BUILD_OPTION="-DCMAKE_BUILD_TYPE=RelWithDebInfo"
 else
-  FLAC_BUILD_OPTION="--enable-debug"
+  FLAC_BUILD_OPTION="--enable-debug=info CFLAGS=-O2 CXXFLAGS=-O2"
   ID3LIB_BUILD_OPTION="--enable-debug=minimum"
   AV_BUILD_OPTION="--enable-debug=1"
   CMAKE_BUILD_OPTION="-DCMAKE_BUILD_TYPE=RelWithDebInfo"
@@ -509,7 +510,7 @@ fi
 
 if test $kernel = "MINGW" || test "$compiler" = "cross-mingw"; then
   # Build zlib only for Windows.
-  ZLIB_ROOT_PATH="$thisdir/zlib-$zlib_version/inst/usr/local"
+  ZLIB_ROOT_PATH="$thisdir/zlib-${zlib_version}.dfsg/inst/usr/local"
   TAGLIB_ZLIB_ROOT_OPTION="-DZLIB_ROOT=${ZLIB_ROOT_PATH}"
   CHROMAPRINT_ZLIB_OPTION="-DEXTRA_LIBS=\"-L${ZLIB_ROOT_PATH}/lib -lz\""
 fi
@@ -625,8 +626,8 @@ if test "$compiler" != "cross-android"; then
   if test -n "$ZLIB_ROOT_PATH"; then
     test -f zlib_${zlib_version}.dfsg-${zlib_patchlevel}.debian.tar.xz ||
       $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_${zlib_version}.dfsg-${zlib_patchlevel}.debian.tar.xz
-    test -f zlib_${zlib_version}.dfsg.orig.tar.gz ||
-      $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_${zlib_version}.dfsg.orig.tar.gz
+    test -f zlib_${zlib_version}.dfsg.orig.tar.bz2 ||
+      $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_${zlib_version}.dfsg.orig.tar.bz2
   fi
 
   test -f ffmpeg_${ffmpeg_version}.orig.tar.xz ||
@@ -639,10 +640,8 @@ if test "$compiler" != "cross-android"; then
   test -f chromaprint_${chromaprint_version}-${chromaprint_patchlevel}.debian.tar.xz ||
     $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/c/chromaprint/chromaprint_${chromaprint_version}-${chromaprint_patchlevel}.debian.tar.xz
 
-  test -f mp4v2_${mp4v2_version}~dfsg0.orig.tar.bz2 ||
-    $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_${mp4v2_version}~dfsg0.orig.tar.bz2
-  test -f mp4v2_${mp4v2_version}~dfsg0-${mp4v2_patchlevel}.debian.tar.xz ||
-    $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_${mp4v2_version}~dfsg0-${mp4v2_patchlevel}.debian.tar.xz
+  test -f mp4v2-${mp4v2_version}.tar.bz2 ||
+    $DOWNLOAD https://github.com/enzo1982/mp4v2/releases/download/v${mp4v2_version}/mp4v2-${mp4v2_version}.tar.bz2
 
 fi # !cross-android
 
@@ -873,8 +872,8 @@ if test "$compiler" != "cross-android"; then
     if ! test -d zlib-${zlib_version}; then
       echo "### Extracting zlib"
 
-      tar xzf source/zlib_${zlib_version}.dfsg.orig.tar.gz
-      cd zlib-${zlib_version}/
+      tar xjf source/zlib_${zlib_version}.dfsg.orig.tar.bz2
+      cd zlib-${zlib_version}.dfsg/
 
       tar xJf ../source/zlib_${zlib_version}.dfsg-${zlib_patchlevel}.debian.tar.xz || true
       echo Can be ignored: Cannot create symlink to debian.series
@@ -907,11 +906,11 @@ if test "$compiler" != "cross-android"; then
     cd ..
   fi
 
-  if ! test -d flac-${libflac_version}; then
+  if ! test -d flac-${libflac_version%+ds*}; then
     echo "### Extracting libflac"
 
     tar xJf source/flac_${libflac_version}.orig.tar.xz
-    cd flac-${libflac_version}/
+    cd flac-${libflac_version%+ds*}/
     tar xJf ../source/flac_${libflac_version}-${libflac_patchlevel}.debian.tar.xz
     for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
     patch -p1 <$srcdir/packaging/patches/flac-1.2.1-00-size_t_max.patch
@@ -959,19 +958,7 @@ if test "$compiler" != "cross-android"; then
   if ! test -d mp4v2-${mp4v2_version}; then
     echo "### Extracting mp4v2"
 
-    tar xjf source/mp4v2_${mp4v2_version}~dfsg0.orig.tar.bz2
-    cd mp4v2-${mp4v2_version}/
-    tar xJf ../source/mp4v2_${mp4v2_version}~dfsg0-${mp4v2_patchlevel}.debian.tar.xz
-    for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
-    if test $kernel = "MINGW" || test "$compiler" = "cross-mingw"; then
-      patch -p1 <$srcdir/packaging/patches/mp4v2-1.0.0-win00-platform.patch
-      if test -z "${cross_host##x86_64*}"; then
-        sed -i '/^#   define _USE_32BIT_TIME_T/ s#^#//#' libplatform/platform_win32.h
-      fi
-    fi
-    patch -p1 <$srcdir/packaging/patches/mp4v2-1.0.0-0005-Cxx11_compiler.patch
-    patch -p1 <$srcdir/packaging/patches/mp4v2-1.0.0-0004-Pointer_comparison.patch
-    cd ..
+    tar xjf source/mp4v2-${mp4v2_version}.tar.bz2
   fi
 
 fi # !cross-android
@@ -1089,37 +1076,11 @@ if test "$compiler" = "cross-android"; then
     cd ..
   fi
 
-  if ! test -d kid3; then
-    echo "### Creating kid3 build directory"
-    mkdir kid3
-    test -e $HOME/Development/ufleisch-release-key.keystore && cp -s $HOME/Development/ufleisch-release-key.keystore kid3/
-    cat >kid3/run-cmake.sh <<EOF
-#!/bin/bash
-_java_root=$_java_root
-_android_sdk_root=$_android_sdk_root
-_android_ndk_root=$_android_ndk_root
-_android_platform=$_android_platform
-_android_ccache=$_android_ccache
-_android_abi=$_android_abi
-_android_qt_root=$_android_qt_root
-_android_keystore_path=\$(pwd)/ufleisch-release-key.keystore
-_android_keystore_alias=ufleisch_android
-if ! test -f "\$_android_keystore_path"; then
-  _android_keystore_path=
-  _android_keystore_alias=
-fi
-_buildprefix=\$(cd ..; pwd)/buildroot/usr/local
-# Pass -DQT_ANDROID_USE_GRADLE=ON to use Gradle instead of ANT.
-cmake -DJAVA_HOME=\$_java_root -DQT_ANDROID_SDK_ROOT=\$_android_sdk_root -DANDROID_NDK=\$_android_ndk_root -DAPK_ALL_TARGET=OFF -DANDROID_ABI=\$_android_abi -DANDROID_EXTRA_LIBS_DIR=\$_buildprefix/lib -DANDROID_KEYSTORE_PATH=\$_android_keystore_path -DANDROID_KEYSTORE_ALIAS=\$_android_keystore_alias -DCMAKE_TOOLCHAIN_FILE=$_android_toolchain_cmake -DANDROID_PLATFORM=$_android_platform -DANDROID_CCACHE=$_android_ccache -DQT_QMAKE_EXECUTABLE=\$_android_qt_root/bin/qmake -DCMAKE_BUILD_TYPE=Release -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} -DPYTHON_EXECUTABLE=/usr/bin/python -DXSLTPROC=/usr/bin/xsltproc -DGZIP_EXECUTABLE=/bin/gzip -DTAGLIBCONFIG_EXECUTABLE=\$_buildprefix/bin/taglib-config -DCMAKE_MAKE_PROGRAM=make $srcdir
-EOF
-    chmod +x kid3/run-cmake.sh
-  fi
-
 else #  cross-android
 
   if test "$1" = "clean"; then
-    for d in zlib-${zlib_version} libogg-${libogg_version} \
-             libvorbis-${libvorbis_version} flac-${libflac_version} \
+    for d in zlib-${zlib_version}.dfsg libogg-${libogg_version} \
+             libvorbis-${libvorbis_version} flac-${libflac_version%+ds*} \
              id3lib-${id3lib_version} taglib-${taglib_version} \
              ffmpeg-${ffmpeg_version} chromaprint-${chromaprint_version} \
              mp4v2-${mp4v2_version}; do
@@ -1174,20 +1135,20 @@ else #  cross-android
     tar xmzf bin/openssl-${openssl_version}.tgz -C $BUILDROOT
   fi
 
-  if test -n "$ZLIB_ROOT_PATH" && test ! -d zlib-${zlib_version}/inst; then
+  if test -n "$ZLIB_ROOT_PATH" && test ! -d zlib-${zlib_version}.dfsg/inst; then
     echo "### Building zlib"
 
-    cd zlib-${zlib_version}/
+    cd zlib-${zlib_version}.dfsg/
+    mkdir -p inst/usr/local
     if test $kernel = "MINGW"; then
-      make -f win32/Makefile.gcc
-      make install -f win32/Makefile.gcc INCLUDE_PATH=`pwd`/inst/usr/local/include LIBRARY_PATH=`pwd`/inst/usr/local/lib BINARY_PATH=`pwd`/inst/usr/local/bin
+      CFLAGS="$CFLAGS -g -O3 -Wall -DNO_FSEEKO" ./configure --static
+      make install prefix=`pwd`/inst/usr/local
     elif test "$compiler" = "cross-mingw"; then
-      make -f win32/Makefile.gcc LOC=-g PREFIX=${_crossprefix}
-      make install -f win32/Makefile.gcc INCLUDE_PATH=`pwd`/inst/usr/local/include LIBRARY_PATH=`pwd`/inst/usr/local/lib BINARY_PATH=`pwd`/inst/usr/local/bin
+      CHOST=${_crossprefix} CFLAGS="$CFLAGS -g -O3 -Wall -DNO_FSEEKO" ./configure --static
+      make install prefix=`pwd`/inst/usr/local
     else
       CFLAGS="$CFLAGS -g -O3 -Wall -DNO_FSEEKO" ./configure --static
       sed 's/LIBS=$(STATICLIB) $(SHAREDLIB) $(SHAREDLIBV)/LIBS=$(STATICLIB)/' Makefile >Makefile.inst
-      mkdir -p inst/usr/local
       make install -f Makefile.inst prefix=`pwd`/inst/usr/local
     fi
     cd inst
@@ -1228,10 +1189,10 @@ else #  cross-android
     tar xmzf bin/libvorbis-${libvorbis_version}.tgz -C $BUILDROOT
   fi
 
-  if test ! -d flac-${libflac_version}/inst; then
+  if test ! -d flac-${libflac_version%+ds*}/inst; then
     echo "### Building libflac"
 
-    cd flac-${libflac_version}/
+    cd flac-${libflac_version%+ds*}/
     autoreconf -i
     configure_args="--enable-shared=no --enable-static=yes --with-ogg=$thisdir/libogg-$libogg_version/inst/usr/local --disable-thorough-tests --disable-doxygen-docs --disable-xmms-plugin $FLAC_BUILD_OPTION $CONFIGURE_OPTIONS"
     if test $kernel = "Darwin"; then
@@ -1427,7 +1388,7 @@ else #  cross-android
 
     # The zlib library path was added for MinGW-builds GCC 4.7.2.
     cd chromaprint-${chromaprint_version}/
-    test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF $CHROMAPRINT_ZLIB_OPTION -DFFMPEG_ROOT=$thisdir/ffmpeg-${ffmpeg_version}/inst/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF -DBUILD_TESTS=OFF $CHROMAPRINT_ZLIB_OPTION -DFFMPEG_ROOT=$thisdir/ffmpeg-${ffmpeg_version}/inst/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
     make VERBOSE=1
     mkdir -p inst
     make install DESTDIR=`pwd`/inst
@@ -1442,118 +1403,151 @@ else #  cross-android
     echo "### Building mp4v2"
 
     cd mp4v2-${mp4v2_version}/
-    autoreconf -i
-    test -f Makefile || CXXFLAGS="$CXXFLAGS -g -O2 -DMP4V2_USE_STATIC_LIB" ./configure --enable-shared=no --enable-static=yes --disable-gch $CONFIGURE_OPTIONS
+    test -f Makefile || eval cmake -DBUILD_SHARED=OFF -DBUILD_UTILS=OFF -DBUILD_SHARED_LIBS=OFF $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    make VERBOSE=1
     mkdir -p inst
     make install DESTDIR=`pwd`/inst
+    fixcmakeinst
     cd inst
     tar czf ../../bin/mp4v2-${mp4v2_version}.tgz usr
     cd ../..
     tar xmzf bin/mp4v2-${mp4v2_version}.tgz -C $BUILDROOT
   fi
 
+fi # cross-android, else
+fi # libs
 
-  if ! test -d kid3; then
-    echo "### Creating kid3 build directory"
+if [[ $target = *"package"* ]]; then
 
-    mkdir kid3
-    if test "$compiler" = "cross-mingw"; then
+  if test "$compiler" = "cross-android"; then
+
+    if ! test -d kid3; then
+      echo "### Creating kid3 build directory"
+      mkdir kid3
+      test -e $HOME/Development/ufleisch-release-key.keystore && cp -s $HOME/Development/ufleisch-release-key.keystore kid3/
       cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
+_java_root=$_java_root
+_android_sdk_root=$_android_sdk_root
+_android_ndk_root=$_android_ndk_root
+_android_platform=$_android_platform
+_android_ccache=$_android_ccache
+_android_abi=$_android_abi
+_android_qt_root=$_android_qt_root
+_android_keystore_path=\$(pwd)/ufleisch-release-key.keystore
+_android_keystore_alias=ufleisch_android
+if ! test -f "\$_android_keystore_path"; then
+_android_keystore_path=
+_android_keystore_alias=
+fi
+_buildprefix=\$(cd ..; pwd)/buildroot/usr/local
+# Pass -DQT_ANDROID_USE_GRADLE=ON to use Gradle instead of ANT.
+cmake -DJAVA_HOME=\$_java_root -DQT_ANDROID_SDK_ROOT=\$_android_sdk_root -DANDROID_NDK=\$_android_ndk_root -DAPK_ALL_TARGET=OFF -DANDROID_ABI=\$_android_abi -DANDROID_EXTRA_LIBS_DIR=\$_buildprefix/lib -DANDROID_KEYSTORE_PATH=\$_android_keystore_path -DANDROID_KEYSTORE_ALIAS=\$_android_keystore_alias -DCMAKE_TOOLCHAIN_FILE=$_android_toolchain_cmake -DANDROID_PLATFORM=$_android_platform -DANDROID_CCACHE=$_android_ccache -DQT_QMAKE_EXECUTABLE=\$_android_qt_root/bin/qmake -DCMAKE_BUILD_TYPE=Release -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} -DPYTHON_EXECUTABLE=/usr/bin/python -DXSLTPROC=/usr/bin/xsltproc -DGZIP_EXECUTABLE=/bin/gzip -DTAGLIBCONFIG_EXECUTABLE=\$_buildprefix/bin/taglib-config -DCMAKE_MAKE_PROGRAM=make $srcdir
+EOF
+      chmod +x kid3/run-cmake.sh
+    fi
+
+  else # cross-android
+
+    if ! test -d kid3; then
+      echo "### Creating kid3 build directory"
+
+      mkdir kid3
+      if test "$compiler" = "cross-mingw"; then
+        cat >kid3/run-cmake.sh <<EOF
+#!/bin/bash
 cmake -GNinja $CMAKE_BUILD_OPTION -DCMAKE_TOOLCHAIN_FILE=$thisdir/mingw.cmake -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DCMAKE_CXX_FLAGS="-g -O2 -DMP4V2_USE_STATIC_LIB" -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} ../../kid3
 EOF
-    elif test "$compiler" = "cross-macos"; then
-      cat >kid3/run-cmake.sh <<EOF
+      elif test "$compiler" = "cross-macos"; then
+        cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 test -z \${PATH##$osxprefix/*} || PATH=$osxprefix/bin:$osxsdk/usr/bin:\$PATH
 cmake -GNinja $CMAKE_BUILD_OPTION -DCMAKE_TOOLCHAIN_FILE=$thisdir/osxcross.cmake -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DCMAKE_CXX_FLAGS="-g -O2 -DMP4V2_USE_STATIC_LIB" -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} ../../kid3
 EOF
-    elif test "$compiler" = "gcc-self-contained"; then
-      if test -n "$QTPREFIX"; then
-        _qt_prefix=$QTPREFIX
-      else
-        for d in /opt/qt5/${qt_version}/gcc_64 /opt/qt5/Qt${qt_version}/${qt_version}/gcc_64 $thisdir/Qt*-linux/${qt_version}/gcc_64; do
-          if test -d $d; then
-            _qt_prefix=$d
-            break
-          fi
-        done
-      fi
-      taglib_config_version=$taglib_version
-      taglib_config_version=${taglib_config_version%beta*}
-      cat >kid3/run-cmake.sh <<EOF
+      elif test "$compiler" = "gcc-self-contained"; then
+        if test -n "$QTPREFIX"; then
+          _qt_prefix=$QTPREFIX
+        else
+          for d in /opt/qt5/${qt_version}/gcc_64 /opt/qt5/Qt${qt_version}/${qt_version}/gcc_64 $thisdir/Qt*-linux/${qt_version}/gcc_64; do
+            if test -d $d; then
+              _qt_prefix=$d
+              break
+            fi
+          done
+        fi
+        taglib_config_version=$taglib_version
+        taglib_config_version=${taglib_config_version%beta*}
+        cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
 cmake -GNinja -DCMAKE_CXX_COMPILER=${gcc_self_contained_cxx} -DCMAKE_C_COMPILER=${gcc_self_contained_cc} -DQT_QMAKE_EXECUTABLE=${_qt_prefix}/bin/qmake -DWITH_READLINE=OFF -DBUILD_SHARED_LIBS=ON -DLINUX_SELF_CONTAINED=ON -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_config_version}" -DWITH_QML=ON -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
 EOF
-    elif test $kernel = "Darwin"; then
-      _qt_prefix=${QTPREFIX:-/usr/local/Trolltech/Qt${qt_version}/${qt_version}/clang_64}
-      cat >kid3/run-cmake.sh <<EOF
+      elif test $kernel = "Darwin"; then
+        _qt_prefix=${QTPREFIX:-/usr/local/Trolltech/Qt${qt_version}/${qt_version}/clang_64}
+        cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 INCLUDE=../buildroot/usr/local/include LIB=../buildroot/usr/local/lib cmake -GNinja -DCMAKE_BUILD_TYPE=RelWithDebInfo -DQT_QMAKE_EXECUTABLE=${_qt_prefix}/bin/qmake -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DWITH_DOCBOOKDIR=${_docbook_xsl_dir} ../../kid3
 EOF
-    elif test $kernel = "MINGW"; then
-      _qtToolsMingw=($QTPREFIX/../../Tools/mingw*)
-      _qtToolsMingw=$(realpath $_qtToolsMingw)
-      cat >kid3/run-cmake.sh <<EOF
+      elif test $kernel = "MINGW"; then
+        _qtToolsMingw=($QTPREFIX/../../Tools/mingw*)
+        _qtToolsMingw=$(realpath $_qtToolsMingw)
+        cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 INCLUDE=../buildroot/usr/local/include LIB=../buildroot/usr/local/lib cmake -G "Unix Makefiles" -DCMAKE_BUILD_TYPE=RelWithDebInfo -DQT_QMAKE_EXECUTABLE=${QTPREFIX}/bin/qmake -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DWITH_DOCBOOKDIR=${_docbook_xsl_dir:-$HOME/prg/docbook-xsl-1.72.0} ../../kid3
 EOF
-      _qtPrefixWin=${QTPREFIX//\//\\}
-      _qtPrefixWin=${_qtPrefixWin/\\c/C:}
-      _qtToolsMingwWin=${_qtToolsMingw//\//\\}
-      _qtToolsMingwWin=${_qtToolsMingwWin/\\c/C:}
-      _docbookXslDirWin=${_docbook_xsl_dir//\//\\}
-      _docbookXslDirWin=${_docbookXslDirWin/\\c/C:}
-      cat >kid3/build.bat <<EOF
+        _qtPrefixWin=${QTPREFIX//\//\\}
+        _qtPrefixWin=${_qtPrefixWin/\\c/C:}
+        _qtToolsMingwWin=${_qtToolsMingw//\//\\}
+        _qtToolsMingwWin=${_qtToolsMingwWin/\\c/C:}
+        _docbookXslDirWin=${_docbook_xsl_dir//\//\\}
+        _docbookXslDirWin=${_docbookXslDirWin/\\c/C:}
+        cat >kid3/build.bat <<EOF
 set INCLUDE=../buildroot/usr/local/include
 set LIB=../buildroot/usr/local/lib
 echo ;%PATH%; | find /C /I ";$_qtPrefixWin\bin;"
 if errorlevel 1 (
-  path $_qtPrefixWin\bin;$_qtToolsMingwWin\bin;$_qtToolsMingwWin\opt\bin;C:\Python38;%PATH%
+path $_qtPrefixWin\bin;$_qtToolsMingwWin\bin;$_qtToolsMingwWin\opt\bin;C:\Python38;%PATH%
 )
 cmake -GNinja -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DWITH_DOCBOOKDIR=${_docbookXslDirWin:-%HOME%/prg/docbook-xsl-1.72.0} ../../kid3
 EOF
-      cat >kid3/run.bat <<EOF
+    cat >kid3/run.bat <<EOF
 set thisdir=%~dp0
 echo ;%PATH%; | find /C /I ";$_qtPrefixWin\bin;"
 if errorlevel 1 (
-  path $_qtPrefixWin\bin;$_qtToolsMingwWin\bin;$_qtToolsMingwWin\opt\bin;C:\Python38;%HOME%\prg\dumpbin;%PATH%
+path $_qtPrefixWin\bin;$_qtToolsMingwWin\bin;$_qtToolsMingwWin\opt\bin;C:\Python38;%HOME%\prg\dumpbin;%PATH%
 )
 echo ;%PATH%; | find /C /I ";%thisdir%src\core;"
 if errorlevel 1 (
-  path %thisdir%src\core;%thisdir%src\gui;%PATH%
+path %thisdir%src\core;%thisdir%src\gui;%PATH%
 )
 set QT_PLUGIN_PATH=$_qtPrefixWin\plugins
 start src\app\qt\kid3
 EOF
-    elif test "$compiler" = "gcc-debug"; then
-      taglib_config_version=$taglib_version
-      taglib_config_version=${taglib_config_version%beta*}
-      cat >kid3/run-cmake.sh <<EOF
+      elif test "$compiler" = "gcc-debug"; then
+        taglib_config_version=$taglib_version
+        taglib_config_version=${taglib_config_version%beta*}
+        cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
 cmake -GNinja -DBUILD_SHARED_LIBS=ON -DQT_QMAKE_EXECUTABLE=${QT_PREFIX}/bin/qmake -DLINUX_SELF_CONTAINED=ON -DWITH_READLINE=OFF -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_config_version}" -DWITH_QML=ON -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
 EOF
-    else
-      taglib_config_version=$taglib_version
-      taglib_config_version=${taglib_config_version%beta*}
-      cat >kid3/run-cmake.sh <<EOF
+      else
+        taglib_config_version=$taglib_version
+        taglib_config_version=${taglib_config_version%beta*}
+        cat >kid3/run-cmake.sh <<EOF
 #!/bin/bash
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
 cmake -GNinja -DBUILD_SHARED_LIBS=ON -DLINUX_SELF_CONTAINED=ON -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_config_version}" -DWITH_QML=ON -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
 EOF
-    fi
-    chmod +x kid3/run-cmake.sh
-  fi
+      fi
+      chmod +x kid3/run-cmake.sh
+    fi # test -d kid3
 
-fi # cross-android, else
-fi # libs
+  fi # cross-android, else
 
-if [[ $target = *"package"* ]]; then
   echo "### Building kid3 package"
 
   pushd kid3 >/dev/null
