@@ -26,7 +26,7 @@
 
 #include "kdemainwindow.h"
 #include <kconfigwidgets_version.h>
-#include <KConfig>
+#include <kconfig_version.h>
 #include <KToggleAction>
 #include <KStandardAction>
 #include <KShortcutsDialog>
@@ -315,11 +315,13 @@ void KdeMainWindow::initActions()
       connect(action, &QAction::triggered, app(), &Kid3Application::convertToId3v23);
     }
   }
+#ifdef HAVE_QTMULTIMEDIA
   action = new QAction(QIcon::fromTheme(QLatin1String("media-playback-start")),
                        tr("&Play"), this);
   action->setStatusTip(tr("Play"));
   collection->addAction(QLatin1String("play"), action);
   connect(action, &QAction::triggered, app(), &Kid3Application::playAudio);
+#endif
   m_settingsShowHidePicture = new KToggleAction(tr("Show &Picture"), this);
   m_settingsShowHidePicture->setStatusTip(tr("Show Picture"));
   m_settingsShowHidePicture->setCheckable(true);
@@ -511,11 +513,16 @@ void KdeMainWindow::addDirectoryToRecentFiles(const QString& dirName)
  */
 void KdeMainWindow::readConfig()
 {
-  setAutoSaveSettings();
+  auto cfg = KSharedConfig::openConfig();
+#if KCONFIG_VERSION >= 0x054300
+  auto stateCfg = KSharedConfig::openStateConfig();
+#else
+  auto stateCfg = cfg;
+#endif
+  setAutoSaveSettings(stateCfg->group("MainWindow"));
   m_settingsShowHidePicture->setChecked(!GuiConfig::instance().hidePicture());
   m_settingsAutoHideTags->setChecked(GuiConfig::instance().autoHideTags());
-  auto cfg = KSharedConfig::openConfig();
-  m_fileOpenRecent->loadEntries(cfg->group("Recent Files"));
+  m_fileOpenRecent->loadEntries(stateCfg->group("Recent Files"));
 
   QString entry = cfg->group("MainWindow").readEntry("StatusBar", "Enabled");
   bool statusBarVisible = entry != QLatin1String("Disabled");
@@ -530,7 +537,12 @@ void KdeMainWindow::readConfig()
  */
 void KdeMainWindow::saveConfig()
 {
-  m_fileOpenRecent->saveEntries(KSharedConfig::openConfig()->group("Recent Files"));
+#if KCONFIG_VERSION >= 0x054300
+  auto stateCfg = KSharedConfig::openStateConfig();
+#else
+  auto stateCfg = KSharedConfig::openConfig();
+#endif
+  m_fileOpenRecent->saveEntries(stateCfg->group("Recent Files"));
 }
 
 /**
