@@ -26,8 +26,9 @@
 
 #include "kdeplatformtools.h"
 #include <QtConfig>
+#include <kconfig_version.h>
 #include <KMessageBox>
-#include <KConfig>
+#include <KSharedConfig>
 #include <KIO/CopyJob>
 #include <QUrl>
 #include <QFileDialog>
@@ -57,8 +58,13 @@ KdePlatformTools::~KdePlatformTools()
 ISettings* KdePlatformTools::applicationSettings()
 {
   if (!m_config) {
-    m_settings.reset(new KConfig);
-    m_config.reset(new KdeSettings(m_settings.data()));
+    auto cfg = KSharedConfig::openConfig();
+#if KCONFIG_VERSION >= 0x054300
+    auto stateCfg = KSharedConfig::openStateConfig();
+#else
+    auto stateCfg = cfg;
+#endif
+    m_config.reset(new KdeSettings(cfg, stateCfg));
   }
   return m_config.data();
 }
@@ -295,6 +301,15 @@ QString KdePlatformTools::getExistingDirectory(QWidget* parent,
       : QFileDialog::ShowDirsOnly);
 }
 
+/**
+ * Check if platform has a graphical user interface.
+ * @return true if platform has GUI.
+ */
+bool KdePlatformTools::hasGui() const
+{
+  return true;
+}
+
 /**
  * Display warning dialog.
  * @param parent parent widget
