@@ -42,6 +42,7 @@
 #include "mainwindowconfig.h"
 #include "kid3form.h"
 #include "filelist.h"
+#include "sectionactions.h"
 #include "kid3application.h"
 #include "configdialog.h"
 #include "guiconfig.h"
@@ -134,7 +135,7 @@ void Kid3MainWindow::initActions()
   auto fileOpenDirectory = new QAction(this);
   fileOpenDirectory->setStatusTip(tr("Opens a folder"));
   fileOpenDirectory->setText(tr("O&pen Folder..."));
-  fileOpenDirectory->setShortcut(Qt::CTRL + Qt::Key_D);
+  fileOpenDirectory->setShortcut(Qt::CTRL | Qt::Key_D);
   fileOpenDirectory->setIcon(QIcon::fromTheme(QLatin1String("document-open"),
       QIcon(QLatin1String(":/images/document-open.png"))));
   fileOpenDirectory->setObjectName(QLatin1String("open_directory"));
@@ -304,7 +305,7 @@ void Kid3MainWindow::initActions()
   auto fileQuit = new QAction(this);
   fileQuit->setStatusTip(tr("Quits the application"));
   fileQuit->setText(tr("&Quit"));
-  fileQuit->setShortcut(Qt::CTRL + Qt::Key_Q);
+  fileQuit->setShortcut(Qt::CTRL | Qt::Key_Q);
   fileQuit->setIcon(QIcon::fromTheme(QLatin1String("application-exit"),
       QIcon(QLatin1String(":/images/application-exit.png"))));
   fileQuit->setMenuRole(QAction::QuitRole);
@@ -319,7 +320,7 @@ void Kid3MainWindow::initActions()
   auto editSelectAll = new QAction(this);
   editSelectAll->setStatusTip(tr("Select all files"));
   editSelectAll->setText(tr("Select &All"));
-  editSelectAll->setShortcut(Qt::ALT + Qt::Key_A);
+  editSelectAll->setShortcut(Qt::ALT | Qt::Key_A);
   editSelectAll->setIcon(QIcon::fromTheme(QLatin1String("edit-select-all"),
       QIcon(QLatin1String(":/images/edit-select-all.png"))));
 #if defined Q_OS_MAC && QT_VERSION == 0x050400
@@ -335,7 +336,7 @@ void Kid3MainWindow::initActions()
   auto editDeselect = new QAction(this);
   editDeselect->setStatusTip(tr("Deselect all files"));
   editDeselect->setText(tr("Dese&lect"));
-  editDeselect->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_A);
+  editDeselect->setShortcut(Qt::CTRL | Qt::SHIFT | Qt::Key_A);
   editDeselect->setObjectName(QLatin1String("edit_deselect"));
   m_shortcutsModel->registerAction(editDeselect, menuTitle);
   connect(editDeselect, &QAction::triggered,
@@ -352,10 +353,18 @@ void Kid3MainWindow::initActions()
     app(), &Kid3Application::selectAllInDirectory);
   editMenu->addAction(editSelectAllInDir);
 
+  auto editInvertSelection = new QAction(this);
+  editInvertSelection->setText(tr("&Invert Selection"));
+  editInvertSelection->setObjectName(QLatin1String("invert_selection"));
+  m_shortcutsModel->registerAction(editInvertSelection, menuTitle);
+  connect(editInvertSelection, &QAction::triggered,
+    app(), &Kid3Application::invertSelection);
+  editMenu->addAction(editInvertSelection);
+
   auto editPreviousFile = new QAction(this);
   editPreviousFile->setStatusTip(tr("Select previous file"));
   editPreviousFile->setText(tr("&Previous File"));
-  editPreviousFile->setShortcut(Qt::ALT + Qt::Key_Up);
+  editPreviousFile->setShortcut(Qt::ALT | Qt::Key_Up);
   editPreviousFile->setIcon(QIcon::fromTheme(QLatin1String("go-previous"),
       QIcon(QLatin1String(":/images/go-previous.png"))));
   editPreviousFile->setObjectName(QLatin1String("previous_file"));
@@ -368,7 +377,7 @@ void Kid3MainWindow::initActions()
   auto editNextFile = new QAction(this);
   editNextFile->setStatusTip(tr("Select next file"));
   editNextFile->setText(tr("&Next File"));
-  editNextFile->setShortcut(Qt::ALT + Qt::Key_Down);
+  editNextFile->setShortcut(Qt::ALT | Qt::Key_Down);
   editNextFile->setIcon(QIcon::fromTheme(QLatin1String("go-next"),
       QIcon(QLatin1String(":/images/go-next.png"))));
   editNextFile->setObjectName(QLatin1String("next_file"));
@@ -489,6 +498,7 @@ void Kid3MainWindow::initActions()
     }
   }
 
+#ifdef HAVE_QTMULTIMEDIA
   toolsMenu->addSeparator();
   auto toolsPlay = new QAction(this);
   toolsPlay->setStatusTip(tr("Play"));
@@ -500,6 +510,7 @@ void Kid3MainWindow::initActions()
     app(), &Kid3Application::playAudio);
   toolsMenu->addAction(toolsPlay);
   toolBar->addAction(toolsPlay);
+#endif
 
   menuTitle = tr("&Settings");
   QMenu* settingsMenu = menubar->addMenu(menuTitle);
@@ -616,6 +627,18 @@ void Kid3MainWindow::initActions()
           fileList, &FileList::initUserActions);
 }
 
+/**
+ * Get keyboard shortcuts.
+ * @return mapping of action names to key sequences.
+ */
+QMap<QString, QKeySequence> Kid3MainWindow::shortcutsMap() const
+{
+  if (m_shortcutsModel) {
+    return m_shortcutsModel->shortcutsMap();
+  }
+  return {};
+}
+
 /**
  * Init actions of form.
  */
@@ -698,6 +721,20 @@ void Kid3MainWindow::initFormActions()
   connect(addFormAction(tr("Focus"), QLatin1String("dirlist_focus"), ctx),
           &QAction::triggered,
           form(), &Kid3Form::setFocusDirList);
+
+  const auto sectionShortcuts = SectionActions::defaultShortcuts();
+  ctx = tr("Section");
+  for (auto it = sectionShortcuts.constBegin();
+       it != sectionShortcuts.constEnd();
+       ++it) {
+    const auto& tpl = *it;
+    QAction* action = new QAction(std::get<1>(tpl), this);
+    action->setObjectName(std::get<0>(tpl));
+    action->setShortcut(std::get<2>(tpl));
+    action->setShortcutContext(Qt::WidgetShortcut);
+    action->setEnabled(false);
+    m_shortcutsModel->registerAction(action, ctx);
+  }
 }
 
 /**
@@ -870,7 +907,7 @@ void Kid3MainWindow::slotHelpAbout()
     QLatin1String("<br/><br/>(c) 2003-" RELEASE_YEAR
     " <a href=\"mailto:ufleisch@users.sourceforge.net\">Urs Fleisch</a>"
     "<br/><br/>"
-    "<a href=\"http://kid3.sourceforge.net/\">http://kid3.sourceforge.net</a>"
+    "<a href=\"https://kid3.kde.org/\">https://kid3.kde.org</a>"
     "<br/>") + tr("License") +
     QLatin1String(": <a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">"
     "GNU General Public License</a><br/> "));
@@ -896,6 +933,7 @@ void Kid3MainWindow::slotSettingsConfigure()
   if (dialog->exec() == QDialog::Accepted) {
     dialog->getConfig();
     impl()->applyChangedConfiguration();
+    impl()->applyChangedShortcuts();
   }
 }
 
