@@ -194,9 +194,9 @@ int PlatformTools::warningYesNoCancel(QWidget* parent, const QString& text,
     const QString& caption)
 {
   return QMessageBox::warning(parent, caption, text,
-                              QMessageBox::Yes | QMessageBox::Default,
-                              QMessageBox::No,
-                              QMessageBox::Cancel | QMessageBox::Escape);
+                              QMessageBox::Yes | QMessageBox::No |
+                              QMessageBox::Cancel,
+                              QMessageBox::Yes);
 }
 
 /**
@@ -229,7 +229,7 @@ QString PlatformTools::getOpenFileName(QWidget* parent, const QString& caption,
   return QFileDialog::getOpenFileName(
         parent, caption, dir, filter, selectedFilter,
         MainWindowConfig::instance().dontUseNativeDialogs()
-        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(nullptr));
+        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options());
 }
 
 /**
@@ -248,7 +248,7 @@ QStringList PlatformTools::getOpenFileNames(QWidget* parent,
   return QFileDialog::getOpenFileNames(
         parent, caption, dir, filter, selectedFilter,
         MainWindowConfig::instance().dontUseNativeDialogs()
-        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(nullptr));
+        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options());
 }
 
 /**
@@ -266,7 +266,7 @@ QString PlatformTools::getSaveFileName(QWidget* parent, const QString& caption,
   return QFileDialog::getSaveFileName(
         parent, caption, dir, filter, selectedFilter,
         MainWindowConfig::instance().dontUseNativeDialogs()
-        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options(nullptr));
+        ? QFileDialog::DontUseNativeDialog : QFileDialog::Options());
 }
 
 /**
@@ -285,6 +285,15 @@ QString PlatformTools::getExistingDirectory(QWidget* parent,
       : QFileDialog::ShowDirsOnly);
 }
 
+/**
+ * Check if platform has a graphical user interface.
+ * @return true if platform has GUI.
+ */
+bool PlatformTools::hasGui() const
+{
+  return true;
+}
+
 /**
  * Display warning dialog.
  * @param parent parent widget
