@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Dec 2011
  *
- * Copyright (C) 2011-2013  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -30,23 +30,14 @@
 #include <QLineEdit>
 #include <QHBoxLayout>
 #include <QKeyEvent>
-#if QT_VERSION >= 0x050200
 #include <QKeySequenceEdit>
-#endif
 
 /**
  * Constructor.
  * @param parent parent object
  */
-ShortcutsDelegate::ShortcutsDelegate(QObject* parent) :
-  QItemDelegate(parent), m_resetFlag(false)
-{
-}
-
-/**
- * Destructor.
- */
-ShortcutsDelegate::~ShortcutsDelegate()
+ShortcutsDelegate::ShortcutsDelegate(QObject* parent)
+  : QItemDelegate(parent), m_resetFlag(false)
 {
 }
 
@@ -62,11 +53,17 @@ QWidget* ShortcutsDelegate::createEditor(
   const QModelIndex& index) const
 {
   QWidget* editor = QItemDelegate::createEditor(parent, option, index);
-  if (QLineEdit* le = qobject_cast<QLineEdit*>(editor)) {
-    editor = new ShortcutsDelegateEditor(le, parent);
-    connect(editor, SIGNAL(clearClicked()), this, SLOT(clearAndCloseEditor()));
-    connect(editor, SIGNAL(resetClicked()), this, SLOT(resetToDefault()));
-    connect(editor, SIGNAL(valueEntered()), this, SLOT(commitAndCloseEditor()));
+  if (auto le = qobject_cast<QLineEdit*>(editor)) {
+    auto shortcutsEditor = new ShortcutsDelegateEditor(le, parent);
+    editor = shortcutsEditor;
+    connect(shortcutsEditor, &ShortcutsDelegateEditor::clearClicked,
+            this, &ShortcutsDelegate::clearAndCloseEditor);
+    connect(shortcutsEditor, &ShortcutsDelegateEditor::clearClicked,
+            this, &ShortcutsDelegate::clearAndCloseEditor);
+    connect(shortcutsEditor, &ShortcutsDelegateEditor::resetClicked,
+            this, &ShortcutsDelegate::resetToDefault);
+    connect(shortcutsEditor, &ShortcutsDelegateEditor::valueEntered,
+            this, &ShortcutsDelegate::commitAndCloseEditor);
   }
   return editor;
 }
@@ -76,7 +73,7 @@ QWidget* ShortcutsDelegate::createEditor(
  */
 void ShortcutsDelegate::resetToDefault()
 {
-  if (ShortcutsDelegateEditor* editor =
+  if (auto editor =
       qobject_cast<ShortcutsDelegateEditor*>(sender())) {
     m_resetFlag = true;
     emit commitData(editor);
@@ -89,7 +86,7 @@ void ShortcutsDelegate::resetToDefault()
  */
 void ShortcutsDelegate::commitAndCloseEditor()
 {
-  if (ShortcutsDelegateEditor* editor =
+  if (auto editor =
       qobject_cast<ShortcutsDelegateEditor*>(sender())) {
     emit commitData(editor);
     emit closeEditor(editor);
@@ -101,7 +98,7 @@ void ShortcutsDelegate::commitAndCloseEditor()
  */
 void ShortcutsDelegate::clearAndCloseEditor()
 {
-  if (ShortcutsDelegateEditor* editor =
+  if (auto editor =
       qobject_cast<ShortcutsDelegateEditor*>(sender())) {
     editor->getEditor()->clear();
     emit commitData(editor);
@@ -117,7 +114,7 @@ void ShortcutsDelegate::clearAndCloseEditor()
 void ShortcutsDelegate::setEditorData(
   QWidget* editor, const QModelIndex& index) const
 {
-  if (ShortcutsDelegateEditor* compoundWidget =
+  if (auto compoundWidget =
       qobject_cast<ShortcutsDelegateEditor*>(editor)) {
     QItemDelegate::setEditorData(compoundWidget->getEditor(), index);
   }
@@ -132,7 +129,7 @@ void ShortcutsDelegate::setEditorData(
 void ShortcutsDelegate::setModelData(
   QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const
 {
-  if (ShortcutsDelegateEditor* compoundWidget =
+  if (auto compoundWidget =
       qobject_cast<ShortcutsDelegateEditor*>(editor)) {
     if (m_resetFlag) {
       m_resetFlag = false;
@@ -179,106 +176,24 @@ void ShortcutsDelegate::updateEditorGeometry(
  * @param parent parent widget
  */
 ShortcutsDelegateEditor::ShortcutsDelegateEditor(
-  QLineEdit* lineEdit, QWidget* parent) :
-  QFrame(parent) {
-  QHBoxLayout* hlayout = new QHBoxLayout(this);
+  QLineEdit* lineEdit, QWidget* parent)
+  : QFrame(parent) {
+  auto hlayout = new QHBoxLayout(this);
   hlayout->setContentsMargins(0, 0, 0, 0);
-#if QT_VERSION >= 0x050200
   delete lineEdit;
   m_editor = new QKeySequenceEdit(parent);
-  connect(m_editor, SIGNAL(editingFinished()), this, SIGNAL(valueEntered()));
-#else
-  m_editor = lineEdit;
-  m_editor->setReadOnly(true);
-  m_editor->installEventFilter(this);
-#endif
+  connect(m_editor, &QKeySequenceEdit::editingFinished,
+          this, &ShortcutsDelegateEditor::valueEntered);
   setFocusProxy(m_editor);
   hlayout->addWidget(m_editor, 0, Qt::AlignLeft);
-  QToolButton* clearButton = new QToolButton(this);
+  auto clearButton = new QToolButton(this);
   clearButton->setText(tr("Clear"));
-  connect(clearButton, SIGNAL(clicked()), this, SIGNAL(clearClicked()));
+  connect(clearButton, &QAbstractButton::clicked,
+          this, &ShortcutsDelegateEditor::clearClicked);
   hlayout->addWidget(clearButton);
-  QToolButton* resetButton = new QToolButton(this);
+  auto resetButton = new QToolButton(this);
   resetButton->setText(tr("Reset"));
-  connect(resetButton, SIGNAL(clicked()), this, SIGNAL(resetClicked()));
+  connect(resetButton, &QAbstractButton::clicked,
+          this, &ShortcutsDelegateEditor::resetClicked);
   hlayout->addWidget(resetButton);
 }
-
-/**
- * Destructor.
- */
-ShortcutsDelegateEditor::~ShortcutsDelegateEditor()
-{
-}
-
-#if QT_VERSION < 0x050200
-bool ShortcutsDelegateEditor::event(QEvent* ev)
-{
-  QEvent::Type eventType = ev->type();
-  if (eventType != QEvent::ShortcutOverride &&
-      eventType != QEvent::KeyPress &&
-      eventType != QEvent::KeyRelease)
-    return QFrame::event(ev);
-
-  if (eventType == QEvent::ShortcutOverride) {
-    QKeyEvent* keyEvent = static_cast<QKeyEvent*>(ev);
-    int keyCode = 0;
-
-    // Check modifiers pressed
-    if (keyEvent->modifiers() & Qt::ControlModifier)
-      keyCode |= Qt::ControlModifier;
-    if (keyEvent->modifiers() & Qt::AltModifier)
-      keyCode |= Qt::AltModifier;
-    if (keyEvent->modifiers() & Qt::ShiftModifier)
-      keyCode |= Qt::ShiftModifier;
-    if (keyEvent->modifiers() & Qt::MetaModifier)
-      keyCode |= Qt::MetaModifier;
-
-    switch (keyEvent->key()) {
-    // These keys can't be used
-    case Qt::Key_Shift:
-    case Qt::Key_Control:
-    case Qt::Key_Meta:
-    case Qt::Key_Alt:
-    case Qt::Key_AltGr:
-    case Qt::Key_Super_L:
-    case Qt::Key_Super_R:
-    case Qt::Key_Menu:
-    case Qt::Key_Hyper_L:
-    case Qt::Key_Hyper_R:
-    case Qt::Key_Help:
-    case Qt::Key_Direction_L:
-    case Qt::Key_Direction_R:
-      break;
-
-    default:
-      keyCode |= keyEvent->key();
-    }
-
-    QString keyString = QKeySequence(keyCode).toString();
-    if (!keyString.endsWith(QLatin1Char('+'))) {
-      m_editor->setText(keyString);
-      emit valueEntered();
-    }
-  }
-  return true;
-}
-
-/**
- * Filters events if this object has been installed as an event filter for
- * the @a watched object.
- * @param watched watched object
- * @param ev event
- * @return true to stop further event handling
- */
-bool ShortcutsDelegateEditor::eventFilter(QObject* watched, QEvent* ev)
-{
-  QEvent::Type eventType = ev->type();
-  if (eventType == QEvent::KeyPress ||
-      eventType == QEvent::KeyRelease ||
-      eventType == QEvent::ShortcutOverride)
-    return event(ev);
-  else
-    return QFrame::eventFilter(watched, ev);
-}
-#endif
