@@ -28,6 +28,7 @@
 
 #include <QStringList>
 #include <QScopedPointer>
+#include <QVariantList>
 #include "generalconfig.h"
 #include "kid3api.h"
 
@@ -74,6 +75,9 @@ class KID3_CORE_EXPORT TagConfig : public StoredConfig<TagConfig> {
   /** custom genres for ID3v2.3 */
   Q_PROPERTY(QStringList customGenres READ customGenres WRITE setCustomGenres
              NOTIFY customGenresChanged)
+  /** custom frame names */
+  Q_PROPERTY(QStringList customFrames READ customFrames WRITE setCustomFrames
+             NOTIFY customFramesChanged)
   /** version used for new ID3v2 tags */
   Q_PROPERTY(int id3v2Version READ id3v2Version WRITE setId3v2Version
              NOTIFY id3v2VersionChanged)
@@ -242,6 +246,12 @@ public:
   /** Set custom genres for ID3v2.3. */
   void setCustomGenres(const QStringList& customGenres);
 
+  /** custom frame names */
+  QStringList customFrames() const { return m_customFrames; }
+
+  /** Set custom frame names. */
+  void setCustomFrames(const QStringList& customFrames);
+
   /** version used for new ID3v2 tags */
   int id3v2Version() const;
 
@@ -279,6 +289,18 @@ public:
     return m_quickAccessFrameOrder;
   }
 
+  /**
+   * Available and selected quick access frames.
+   */
+  Q_INVOKABLE QVariantList selectedQuickAccessFrames() const;
+
+  /**
+   * Set selected quick access frames.
+   * @param namesSelected list of maps with name, selected and type fields
+   */
+  Q_INVOKABLE void setSelectedQuickAccessFrames(
+      const QVariantList& namesSelected);
+
   /** Set order of frames which are displayed for Tag 2 even if not present. */
   void setQuickAccessFrameOrder(const QList<int>& frameTypes);
 
@@ -397,6 +419,45 @@ public:
    */
   Q_INVOKABLE static QStringList getRiffTrackNames();
 
+  /**
+   * Convert list of custom frame names to display names.
+   * @param names custom frame names
+   * @return possibly translated display representations of @a names.
+   */
+  Q_INVOKABLE static QStringList customFrameNamesToDisplayNames(
+      const QStringList& names);
+
+  /**
+   * Convert list of display names to custom frame names.
+   * @param displayNames displayed frame names
+   * @return internal representations of @a displayNames.
+   */
+  Q_INVOKABLE static QStringList customFrameNamesFromDisplayNames(
+      const QStringList& displayNames);
+
+  /**
+   * Get the available and selected quick access frames.
+   * @param types ordered frame types as in quickAccessFrameOrder()
+   * @param frameMask quick access frame selection as in quickAccessFrames()
+   * @param customFrameNames list of custom frame names as in customFrames()
+   * @return list of name/type/selected maps.
+   */
+  static QVariantList getQuickAccessFrameSelection(
+      const QList<int>& types, quint64 frameMask,
+      const QStringList& customFrameNames);
+
+  /**
+   * Set the selected quick access frames.
+   * @param namesSelected list of name/type/selected maps
+   * @param frameTypes ordered frame types are returned here,
+   *        suitable for setQuickAccessFrameOrder()
+   * @param frameMask the quick access frame selection is returned here,
+   *        suitable for setQuickAccessFrames()
+   */
+  static void setQuickAccessFrameSelection(
+      const QVariantList& namesSelected,
+      QList<int>& frameTypes, quint64& frameMask);
+
   /**
    * Set default plugin order.
    */
@@ -439,6 +500,9 @@ signals:
   /** Emitted when @a customGenres changed. */
   void customGenresChanged(const QStringList& customGenres);
 
+  /** Emitted when @a customFrames changed. */
+  void customFramesChanged(const QStringList& customFrames);
+
   /** Emitted when @a id3v2Version changed. */
   void id3v2VersionChanged(int id3v2Version);
 
@@ -481,6 +545,7 @@ private:
   QString m_riffTrackName;
   int m_pictureNameItem;
   QStringList m_customGenres;
+  QStringList m_customFrames;
   int m_id3v2Version;
   QString m_textEncodingV1;
   int m_textEncoding;
