@@ -33,8 +33,7 @@
 class ImportTrackDataVector;
 class ImportParser;
 class TrackDataModel;
-class FrameCollection;
-
+class TrackData;
 /**
  * Import tags from text.
  */
@@ -76,6 +75,16 @@ public:
     const QString& extractionFormat,
     ImportTrackDataVector& trackDataVector);
 
+  /**
+   * Import text from tags to other tags.
+   *
+   * @param sourceFormat format to create source text
+   * @param parser import parser which is initialized with extraction format
+   * @param trackData track data to process
+   */
+  static void importFromTags(
+      const QString& sourceFormat, ImportParser& parser, TrackData& trackData);
+
 private:
   Q_DISABLE_COPY(TextImporter)
 
@@ -88,7 +97,7 @@ private:
    *
    * @return true if one or more field were found.
    */
-  bool parseHeader(FrameCollection& frames);
+  bool parseHeader(TrackData& frames);
 
   /**
    * Get next line as frames from imported file or clipboard.
@@ -100,7 +109,7 @@ private:
    * @return true if ok (result in st),
    *         false if end of file reached.
    */
-  bool getNextTags(FrameCollection& frames, bool start);
+  bool getNextTags(TrackData& frames, bool start);
 
   /**
    * Get list with track durations.
