@@ -95,16 +95,22 @@ QUrl DownloadClient::getImageUrl(const QUrl& url)
     return url;
 
   QUrl imgurl;
-  QMap<QString, QString> urlMap =
+  QList<QPair<QString, QString>> urlMap =
       ImportConfig::instance().matchPictureUrlMap();
   for (auto it = urlMap.constBegin(); it != urlMap.constEnd(); ++it) {
-    QRegularExpression re(it.key());
-    QRegularExpressionMatch match = re.match(
+    QRegularExpression re(it->first);
+#if QT_VERSION >= 0x060000
+    auto match = re.match(
+          urlStr, 0, QRegularExpression::NormalMatch,
+          QRegularExpression::AnchorAtOffsetMatchOption);
+#else
+    auto match = re.match(
           urlStr, 0, QRegularExpression::NormalMatch,
           QRegularExpression::AnchoredMatchOption);
+#endif
     if (match.hasMatch()) {
       QString newUrl = urlStr;
-      newUrl.replace(re, *it);
+      newUrl.replace(re, it->second);
       if (newUrl.indexOf(QLatin1String("%25")) != -1) {
         // double URL encoded: first decode
         newUrl = QUrl::fromPercentEncoding(newUrl.toUtf8());
