@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 12 Aug 2011
  *
- * Copyright (C) 2011  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TEXTTABLEMODEL_H
-#define TEXTTABLEMODEL_H
+#pragma once
 
 #include <QAbstractTableModel>
 #include <QList>
@@ -41,19 +40,19 @@ public:
    * Constructor.
    * @param parent parent widget
    */
-  explicit TextTableModel(QObject* parent = 0);
+  explicit TextTableModel(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~TextTableModel();
+  virtual ~TextTableModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const;
+  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -62,7 +61,7 @@ public:
    * @return data for role
    */
   virtual QVariant data(const QModelIndex& index,
-                        int role=Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const override;
 
   /**
    * Get data for header section.
@@ -72,7 +71,7 @@ public:
    * @return header data for role
    */
   virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role=Qt::DisplayRole) const;
+                              int role = Qt::DisplayRole) const override;
 
   /**
    * Get number of rows.
@@ -80,7 +79,7 @@ public:
    * @return number of rows,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int rowCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
@@ -88,7 +87,7 @@ public:
    * @return number of columns,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int columnCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Set the text to be displayed in the table.
@@ -102,5 +101,3 @@ private:
   QList<QStringList> m_cells;
   bool m_hasHeaderLine;
 };
-
-#endif // TEXTTABLEMODEL_H
