@@ -32,6 +32,11 @@
 #include <QCoreApplication>
 #include <QFile>
 #include <QTextStream>
+#if QT_VERSION >= 0x060000
+#include <QStringConverter>
+#else
+#include <QTextCodec>
+#endif
 #include "pictureframe.h"
 
 namespace {
@@ -318,6 +323,7 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
     { "egid", QT_TRANSLATE_NOOP("@default", "Podcast GUID") },
     { "cmID", QT_TRANSLATE_NOOP("@default", "Composer ID") },
     { "xid ", QT_TRANSLATE_NOOP("@default", "XID") },
+    { "Chapters", QT_TRANSLATE_NOOP("@default", "Chapters") },
     { "IARL", QT_TRANSLATE_NOOP("@default", "Archival Location") },
     { "ICMS", QT_TRANSLATE_NOOP("@default", "Commissioned") },
     { "ICRP", QT_TRANSLATE_NOOP("@default", "Cropped") },
@@ -525,6 +531,25 @@ void Frame::setValueAsNumber(int n)
   }
 }
 
+/**
+ * Check if the value of this frame is fuzzy equal to another frame.
+ * Other than with strict equality, total values and some fields which are
+ * not supported in all tag formats are ignored.
+ * @param other frame to compare
+ * @return true if more or less equal.
+ */
+bool Frame::isFuzzyEqual(const Frame& other) const
+{
+  if (getType() == FT_Track || getType() == FT_Disc) {
+    return getValueAsNumber() == other.getValueAsNumber();
+  }
+  return (getValue() == other.getValue() &&
+          (getFieldList().isEmpty() ||
+           other.getFieldList().isEmpty() ||
+           Field::fuzzyCompareFieldLists(getFieldList(),
+                                         other.getFieldList())));
+}
+
 /**
  * Get the value of a field.
  *
@@ -567,9 +592,32 @@ bool Frame::setValueFromFile(const QString& fileName)
 {
   if (!fileName.isEmpty()) {
     QFile file(fileName);
-    if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-      QTextStream stream(&file);
-      setValueIfChanged(stream.readAll());
+
+    if (file.open(QIODevice::ReadOnly)) {
+      QString value;
+      QByteArray data = file.readAll();
+#if QT_VERSION >= 0x060000
+      auto toUtf8 = QStringDecoder(QStringConverter::Utf8);
+      value = toUtf8(data);
+      if (toUtf8.hasError()) {
+        auto encoding = QStringConverter::encodingForData(data);
+        auto decoder = QStringDecoder(encoding.value_or(QStringConverter::Latin1));
+        value = decoder(data);
+      }
+#else
+      QTextCodec::ConverterState state;
+      if (QTextCodec* codec = QTextCodec::codecForName("UTF-8")) {
+        value = codec->toUnicode(data.constData(), data.size(), &state);
+        if (state.invalidChars > 0) {
+          codec = QTextCodec::codecForUtfText(
+                data, QTextCodec::codecForName("ISO 8859-1"));
+          if (codec) {
+            value = codec->toUnicode(data.constData(), data.size());
+          }
+        }
+      }
+#endif
+      setValueIfChanged(value);
       file.close();
       return true;
     }
@@ -586,9 +634,8 @@ bool Frame::writeValueToFile(const QString& fileName) const
 {
   if (!fileName.isEmpty()) {
     QFile file(fileName);
-    if (file.open(QIODevice::WriteOnly | QIODevice::Text)) {
-      QTextStream stream(&file);
-      stream << m_value;
+    if (file.open(QIODevice::WriteOnly)) {
+      file.write(m_value.toUtf8());
       file.close();
       return true;
     }
@@ -1419,7 +1466,10 @@ FrameCollection::const_iterator FrameCollection::searchByName(
 #if QT_VERSION >= 0x060000
       if (ucName == ucFrameName.left(len))
 #else
-      if (ucName == ucFrameName.leftRef(len))
+      // Do not return ASF "Rating Information" when searching for "Rating".
+      if (ucName == ucFrameName.leftRef(len) &&
+          !(ucName == QLatin1String("RATING") &&
+            ucFrameName == QLatin1String("RATING INFORMATION")))
 #endif
       {
         return it;
