@@ -49,6 +49,7 @@
 #include "playlistconfig.h"
 #include "externalprocess.h"
 #include "commandformatreplacer.h"
+#include "config.h"
 
 namespace {
 
@@ -154,7 +155,7 @@ void OutputViewer::append(const QString& text)
   while (startPos < txtLen) {
     QChar ch;
     int len;
-    int crLfPos = txt.indexOf(QRegExp(QLatin1String("[\\r\\n]")), startPos);
+    int crLfPos = txt.indexOf(QRegularExpression(QLatin1String("[\\r\\n]")), startPos);
     if (crLfPos >= startPos) {
       ch = txt.at(crLfPos);
       len = crLfPos - startPos;
@@ -368,10 +369,12 @@ void FileList::contextMenu(const QModelIndex& index, const QPoint& pos)
     if (m_deleteAction) {
       menu.addAction(m_deleteAction);
     }
+#ifdef HAVE_QTMULTIMEDIA
 #if QT_VERSION >= 0x050600
     menu.addAction(tr("&Play"), m_mainWin, &BaseMainWindowImpl::slotPlayAudio);
 #else
     menu.addAction(tr("&Play"), m_mainWin, SLOT(slotPlayAudio()));
+#endif
 #endif
     if (isPlaylist) {
       QAction* editPlaylistAction = new QAction(tr("E&dit"), &menu);
@@ -567,7 +570,7 @@ void FileList::executeContextCommand(int id)
       QMessageBox::warning(
         this, menuCmd.getName(),
         tr("Could not execute ") + args.join(QLatin1String(" ")),
-        QMessageBox::Ok, Qt::NoButton);
+        QMessageBox::Ok, QMessageBox::NoButton);
     }
   }
 }
