@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jun 2009
  *
- * Copyright (C) 2003-2007  Urs Fleisch
+ * Copyright (C) 2003-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef IMAGEVIEWER_H
-#define IMAGEVIEWER_H
+#pragma once
 
 #include <QDialog>
 
@@ -34,7 +33,7 @@ class QLabel;
 
 /** Window to view image */
 class ImageViewer : public QDialog {
-Q_OBJECT
+  Q_OBJECT
 public:
   /**
    * Constructor.
@@ -47,11 +46,9 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ImageViewer() {}
+  virtual ~ImageViewer() override {}
 
 private:
   /** image to view */
   QLabel* m_image;
 };
-
-#endif // IMAGEVIEWER_H
