@@ -740,7 +740,7 @@ void DiscogsImporter::HtmlImpl::parseFindResults(const QByteArray& searchStr)
   // <a class="search_result_title " href="/Amon-Amarth-The-Avenger/release/761529-Amon-Amarth-The-Avenger" data-followable="true">The Avenger</a>
   QString str = QString::fromUtf8(searchStr);
   QRegularExpression idTitleRe(QLatin1String(
-      "<a href=\"/artist/[^>]+?>([^<]+?)</a>[^-]*?-"
+      "href=\"/artist/[^>]+?>([^<]+?)</a>[^-]*?-"
       "\\s*?<a class=\"search_result_title[ \"]+?href=\"/([^/]*?/?release)/"
       "([0-9]+-[^\"]+?)\"[^>]*?>([^<]+?)</a>(.*?card_actions)"),
        QRegularExpression::DotMatchesEverythingOption);
@@ -930,6 +930,7 @@ void DiscogsImporter::HtmlImpl::parseAlbumResults(const QByteArray& albumStr)
           genreStr.replace(nlSpaceRe, QLatin1String(""));
           genreStr = removeHtml(genreStr); // strip HTML tags and entities
           genreStr.remove(QLatin1String("RockStyle:"));
+          genreStr.remove(QLatin1String("PopStyle:"));
           if (genreStr.indexOf(QLatin1Char(',')) >= 0) {
             genreList += genreStr.split(QRegularExpression(QLatin1String(",\\s*")));
           } else {
@@ -1472,6 +1473,20 @@ void DiscogsImporter::sendFindQuery(
   const ServerImporterConfig* cfg,
   const QString& artist, const QString& album)
 {
+  // If an URL is entered in the first search field, its result will be directly
+  // available in the album results list.
+  if (artist.startsWith(QLatin1String("https://www.discogs.com/"))) {
+    const int catBegin = 24;
+    int catEnd = artist.indexOf(QLatin1Char('/'), catBegin);
+    if (catEnd > catBegin) {
+      m_htmlImpl->albumListModel()->clear();
+      m_htmlImpl->albumListModel()->appendItem(
+            artist,
+            artist.mid(catBegin, catEnd - catBegin),
+            artist.mid(catEnd + 1));
+      return;
+    }
+  }
   m_impl = selectImpl(cfg);
   m_impl->sendFindQuery(cfg, artist, album);
 }
