@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 23 Jul 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -27,11 +27,11 @@
 #include "id3libmetadataplugin.h"
 #include "mp3file.h"
 
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2(Id3libMetadataPlugin, Id3libMetadataPlugin)
-#endif
+namespace {
 
-static const QLatin1String TAGGEDFILE_KEY("Id3libMetadata");
+const QLatin1String TAGGEDFILE_KEY("Id3libMetadata");
+
+}
 
 /*!
  * Constructor.
@@ -42,13 +42,6 @@ Id3libMetadataPlugin::Id3libMetadataPlugin(QObject* parent) : QObject(parent)
   setObjectName(QLatin1String("Id3libMetadata"));
 }
 
-/**
- * Destructor.
- */
-Id3libMetadataPlugin::~Id3libMetadataPlugin()
-{
-}
-
 /**
  * Get name of factory, the same as the QObject::objectName() of the plugin.
  * @return factory name.
@@ -64,7 +57,7 @@ QString Id3libMetadataPlugin::name() const
  */
 QStringList Id3libMetadataPlugin::taggedFileKeys() const
 {
-  return QStringList() << TAGGEDFILE_KEY;
+  return {TAGGEDFILE_KEY};
 }
 
 /**
@@ -116,7 +109,7 @@ TaggedFile* Id3libMetadataPlugin::createTaggedFile(
       return new Mp3File(idx);
     }
   }
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -130,8 +123,7 @@ QStringList
 Id3libMetadataPlugin::supportedFileExtensions(const QString& key) const
 {
   if (key == TAGGEDFILE_KEY) {
-    return QStringList() << QLatin1String(".mp3") << QLatin1String(".mp2")
-                         << QLatin1String(".aac");
+    return {QLatin1String(".mp3"), QLatin1String(".mp2"), QLatin1String(".aac")};
   }
   return QStringList();
 }
