@@ -28,7 +28,11 @@
 
 #include <QDir>
 #include <QString>
+#if QT_VERSION >= 0x060000
+#include <QStringConverter>
+#else
 #include <QTextCodec>
+#endif
 #include <QByteArray>
 #include <QtEndian>
 
@@ -61,8 +65,14 @@
 
 namespace {
 
+#if QT_VERSION >= 0x060000
+/** String decoder for ID3v1 tags, default is ISO 8859-1 */
+QStringDecoder s_decoderV1;
+QStringEncoder s_encoderV1;
+#else
 /** Text codec for ID3v1 tags, 0 to use default (ISO 8859-1) */
 const QTextCodec* s_textCodecV1 = nullptr;
+#endif
 
 /** Default text encoding */
 ID3_TextEnc s_defaultTextEncoding = ID3TE_ISO8859_1;
@@ -78,7 +88,7 @@ ID3_TextEnc getDefaultTextEncoding() { return s_defaultTextEncoding; }
 /**
  * Constructor.
  *
- * @param idx index in file proxy model
+ * @param idx index in tagged file system model
  */
 Mp3File::Mp3File(const QPersistentModelIndex& idx)
   : TaggedFile(idx)
@@ -285,7 +295,13 @@ QString fixUpUnicode(const unicode_t* str, size_t numChars)
  * @return string,
  *         "" if the field does not exist.
  */
-QString getString(ID3_Field* field, const QTextCodec* codec = nullptr)
+QString getString(ID3_Field* field,
+#if QT_VERSION >= 0x060000
+                  QStringDecoder* decoder = nullptr
+#else
+                  const QTextCodec* codec = nullptr
+#endif
+    )
 {
   QString text(QLatin1String(""));
   if (field != nullptr) {
@@ -309,8 +325,13 @@ QString getString(ID3_Field* field, const QTextCodec* codec = nullptr)
       // (enc == ID3TE_ISO8859_1 || enc == ID3TE_UTF8)
       size_t numItems = field->GetNumTextItems();
       if (numItems <= 1) {
+#if QT_VERSION >= 0x060000
+        text = decoder ? decoder->decode(QByteArray(field->GetRawText(), field->Size()))
+                       : QString::fromLatin1(field->GetRawText());
+#else
         text = codec ? codec->toUnicode(field->GetRawText(), field->Size())
                      : QString::fromLatin1(field->GetRawText());
+#endif
       } else {
         // if there are multiple items, put them into one string
         // separated by a special separator.
@@ -339,7 +360,12 @@ QString getString(ID3_Field* field, const QTextCodec* codec = nullptr)
  *         QString::null if the tags do not exist.
  */
 QString getTextField(const ID3_Tag* tag, ID3_FrameID id,
-                     const QTextCodec* codec = nullptr)
+#if QT_VERSION >= 0x060000
+                     QStringDecoder* decoder = nullptr
+#else
+                     const QTextCodec* codec = nullptr
+#endif
+    )
 {
   if (!tag) {
     return QString();
@@ -348,7 +374,11 @@ QString getTextField(const ID3_Tag* tag, ID3_FrameID id,
   ID3_Field* fld;
   ID3_Frame* frame = tag->Find(id);
   if (frame && ((fld = frame->GetField(ID3FN_TEXT)) != nullptr)) {
+#if QT_VERSION >= 0x060000
+    str = getString(fld, decoder);
+#else
     str = getString(fld, codec);
+#endif
   }
   return str;
 }
@@ -407,7 +437,11 @@ int getGenreNum(const ID3_Tag* tag)
   if ((str[0] == QLatin1Char('(')) &&
       ((cpPos = str.indexOf(QLatin1Char(')'), 2)) > 1)) {
     bool ok;
+#if QT_VERSION >= 0x060000
+    n = str.mid(1, cpPos - 1).toInt(&ok);
+#else
     n = str.midRef(1, cpPos - 1).toInt(&ok);
+#endif
     if (!ok || n > 0xff) {
       n = 0xff;
     }
@@ -507,7 +541,12 @@ void setStringList(ID3_Field* field, const QStringList& lst)
  * @param codec        text codec to use, 0 for default
  */
 void setString(ID3_Field* field, const QString& text,
-               const QTextCodec* codec = nullptr)
+#if QT_VERSION >= 0x060000
+               QStringEncoder* encoder = nullptr
+#else
+               const QTextCodec* codec = nullptr
+#endif
+    )
 {
   if (text.indexOf(Frame::stringListSeparator()) == -1) {
     ID3_TextEnc enc = field->GetEncoding();
@@ -522,8 +561,13 @@ void setString(ID3_Field* field, const QString& text,
       field->Set(text.toUtf8().data());
     } else {
       // enc == ID3TE_ISO8859_1
+#if QT_VERSION >= 0x060000
+      field->Set(encoder ? static_cast<QByteArray>(encoder->encode(text)).constData()
+                       : text.toLatin1().constData());
+#else
       field->Set(codec ? codec->fromUnicode(text).constData()
                        : text.toLatin1().constData());
+#endif
     }
   } else {
     setStringList(field, text.split(Frame::stringListSeparator()));
@@ -545,7 +589,13 @@ void setString(ID3_Field* field, const QString& text,
  */
 bool setTextField(ID3_Tag* tag, ID3_FrameID id, const QString& text,
                   bool allowUnicode = false, bool replace = true,
-                  bool removeEmpty = true, const QTextCodec* codec = nullptr)
+                  bool removeEmpty = true,
+#if QT_VERSION >= 0x060000
+                  QStringEncoder* encoder = nullptr
+#else
+                  const QTextCodec* codec = nullptr
+#endif
+    )
 {
   bool changed = false;
   if (tag && !text.isNull()) {
@@ -587,7 +637,11 @@ bool setTextField(ID3_Tag* tag, ID3_FrameID id, const QString& text,
             encfld->Set(enc);
           }
           fld->SetEncoding(enc);
+#if QT_VERSION >= 0x060000
+          setString(fld, text, encoder);
+#else
           setString(fld, text, codec);
+#endif
           tag->AttachFrame(frame);
         }
       }
@@ -984,7 +1038,8 @@ ID3_FrameID getId3libFrameIdForType(Frame::Type type)
   } else if (type == Frame::FT_CatalogNumber ||
              type == Frame::FT_ReleaseCountry ||
              type == Frame::FT_Grouping ||
-             type == Frame::FT_Subtitle) {
+             type == Frame::FT_Subtitle ||
+             (Frame::isCustomFrameType(type))) {
     return ID3FID_USERTEXT;
   }
 
@@ -1065,7 +1120,11 @@ QVariantList syltBytesToList(const QByteArray& bytes, ID3_TextEnc enc)
       // starting with FEFF BOM
       // fallthrough
     case ID3TE_UTF16:
+#if QT_VERSION >= 0x060000
+      str = QString::fromUtf16(reinterpret_cast<const char16_t*>(text.constData()));
+#else
       str = QString::fromUtf16(reinterpret_cast<const ushort*>(text.constData()));
+#endif
       break;
     case ID3TE_UTF8:
       str = QString::fromUtf8(text.constData());
@@ -1331,9 +1390,15 @@ void Mp3File::setId3v2Frame(ID3_Frame* id3Frame, const Frame& frame) const
       break;
     }
     const Frame::Field& fld = *fldIt;
+#if QT_VERSION >= 0x060000
+    switch (fld.m_value.typeId()) {
+      case QMetaType::Int:
+      case QMetaType::UInt:
+#else
     switch (fld.m_value.type()) {
       case QVariant::Int:
       case QVariant::UInt:
+#endif
       {
         int intVal = fld.m_value.toInt();
         if (fld.m_id == ID3FN_TEXTENC) {
@@ -1344,14 +1409,19 @@ void Mp3File::setId3v2Frame(ID3_Frame* id3Frame, const Frame& frame) const
         break;
       }
 
+#if QT_VERSION >= 0x060000
+      case QMetaType::QString:
+#else
       case QVariant::String:
+#endif
       {
         if (enc != ID3TE_NONE) {
           id3Field->SetEncoding(enc);
         }
         QString value(fld.m_value.toString());
         if (id3Id == ID3FID_CONTENTTYPE) {
-          if (!TagConfig::instance().genreNotNumeric()) {
+          if (!TagConfig::instance().genreNotNumeric() ||
+              value.contains(Frame::stringListSeparator())) {
             value = Genres::getNumberString(value, true);
           }
         } else if (id3Id == ID3FID_TRACKNUM) {
@@ -1361,7 +1431,11 @@ void Mp3File::setId3v2Frame(ID3_Frame* id3Frame, const Frame& frame) const
         break;
       }
 
+#if QT_VERSION >= 0x060000
+      case QMetaType::QByteArray:
+#else
       case QVariant::ByteArray:
+#endif
       {
         const QByteArray& ba = fld.m_value.toByteArray();
         id3Field->Set(reinterpret_cast<const unsigned char*>(ba.data()),
@@ -1369,7 +1443,11 @@ void Mp3File::setId3v2Frame(ID3_Frame* id3Frame, const Frame& frame) const
         break;
       }
 
+#if QT_VERSION >= 0x060000
+      case QMetaType::QVariantList:
+#else
       case QVariant::List:
+#endif
       {
         if (id3Id == ID3FID_SYNCEDLYRICS) {
           QByteArray ba = syltListToBytes(fld.m_value.toList(), enc);
@@ -1389,7 +1467,11 @@ void Mp3File::setId3v2Frame(ID3_Frame* id3Frame, const Frame& frame) const
       }
 
       default:
+#if QT_VERSION >= 0x060000
+        qDebug("Unknown type %d in field %d", fld.m_value.typeId(), fld.m_id);
+#else
         qDebug("Unknown type %d in field %d", fld.m_value.type(), fld.m_id);
+#endif
     }
   }
 #ifdef Q_OS_WIN32
@@ -1427,13 +1509,25 @@ bool Mp3File::getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) c
     return false;
 
   const ID3_Tag* tag;
+#if QT_VERSION >= 0x060000
+  QStringDecoder* decoder;
+#else
   const QTextCodec* codec;
+#endif
   if (tagNr == Frame::Tag_1) {
     tag = m_tagV1.data();
+#if QT_VERSION >= 0x060000
+    decoder = &s_decoderV1;
+#else
     codec = s_textCodecV1;
+#endif
   } else if (tagNr == Frame::Tag_2) {
     tag = m_tagV2.data();
+#if QT_VERSION >= 0x060000
+    decoder = nullptr;
+#else
     codec = nullptr;
+#endif
   } else {
     return false;
   }
@@ -1443,7 +1537,11 @@ bool Mp3File::getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) c
   case Frame::FT_Artist:
   case Frame::FT_Comment:
   case Frame::FT_Title:
+#if QT_VERSION >= 0x060000
+    frame.setValue(getTextField(tag, frameId, decoder));
+#else
     frame.setValue(getTextField(tag, frameId, codec));
+#endif
     break;
   case Frame::FT_Track:
     if (tagNr == Frame::Tag_1) {
@@ -1509,7 +1607,8 @@ bool Mp3File::setFrame(Frame::TagNumber tagNr, const Frame& frame)
               (fld = id3Frame->GetField(ID3FN_DESCRIPTION)) != nullptr) {
             ID3_FrameID id = id3Frame->GetID();
             if (id == ID3FID_CONTENTTYPE) {
-              if (!TagConfig::instance().genreNotNumeric()) {
+              if (!TagConfig::instance().genreNotNumeric() ||
+                  value.contains(Frame::stringListSeparator())) {
                 value = Genres::getNumberString(value, true);
               }
             } else if (id == ID3FID_TRACKNUM) {
@@ -1624,15 +1723,30 @@ bool Mp3File::setFrame(Frame::TagNumber tagNr, const Frame& frame)
     return false;
 
   ID3_Tag* tag;
+#if QT_VERSION >= 0x060000
+  QStringDecoder* decoder;
+  QStringEncoder* encoder;
+#else
   const QTextCodec* codec;
+#endif
   bool allowUnicode;
   if (tagNr == Frame::Tag_1) {
     tag = m_tagV1.data();
+#if QT_VERSION >= 0x060000
+    decoder = &s_decoderV1;
+    encoder = &s_encoderV1;
+#else
     codec = s_textCodecV1;
+#endif
     allowUnicode = false;
   } else if (tagNr == Frame::Tag_2) {
     tag = m_tagV2.data();
+#if QT_VERSION >= 0x060000
+    decoder = nullptr;
+    encoder = nullptr;
+#else
     codec = nullptr;
+#endif
     allowUnicode = true;
   } else {
     return false;
@@ -1645,13 +1759,22 @@ bool Mp3File::setFrame(Frame::TagNumber tagNr, const Frame& frame)
   case Frame::FT_Title:
   {
     QString str = frame.getValue();
+#if QT_VERSION >= 0x060000
+    if (getTextField(tag, frameId, decoder) != str &&
+        setTextField(tag, frameId, str, allowUnicode, true, true, encoder)) {
+#else
     if (getTextField(tag, frameId, codec) != str &&
         setTextField(tag, frameId, str, allowUnicode, true, true, codec)) {
+#endif
       markTagChanged(tagNr, type);
       QString s = checkTruncation(tagNr, str, 1ULL << type,
                                   type == Frame::FT_Comment ? 28 : 30);
-      if (!s.isNull()) setTextField(tag, frameId, s, allowUnicode, true, true,
-                                    codec);
+      if (!s.isNull())
+#if QT_VERSION >= 0x060000
+        setTextField(tag, frameId, s, allowUnicode, true, true, encoder);
+#else
+        setTextField(tag, frameId, s, allowUnicode, true, true, codec);
+#endif
     }
     break;
   }
@@ -1679,7 +1802,9 @@ bool Mp3File::setFrame(Frame::TagNumber tagNr, const Frame& frame)
     } else {
       if (!str.isNull()) {
         int num = 0xff;
-        if (!TagConfig::instance().genreNotNumeric()) {
+        if (str.contains(Frame::stringListSeparator())) {
+          str = Genres::getNumberString(str, true);
+        } else if (!TagConfig::instance().genreNotNumeric()) {
           num = Genres::getNumber(str);
         }
         if (num >= 0 && num != 0xff) {
@@ -1688,8 +1813,13 @@ bool Mp3File::setFrame(Frame::TagNumber tagNr, const Frame& frame)
             markTagChanged(tagNr, type);
           }
         } else {
+#if QT_VERSION >= 0x060000
+          if (getTextField(tag, frameId, decoder) != str &&
+              setTextField(tag, frameId, str, allowUnicode, true, true, encoder)) {
+#else
           if (getTextField(tag, frameId, codec) != str &&
               setTextField(tag, frameId, str, allowUnicode, true, true, codec)) {
+#endif
             markTagChanged(tagNr, type);
           }
         }
@@ -1731,7 +1861,7 @@ ID3_Frame* Mp3File::createId3FrameFromFrame(Frame& frame) const
 {
   ID3_Frame* id3Frame = nullptr;
   ID3_FrameID id;
-  if (frame.getType() != Frame::FT_Other) {
+  if (!Frame::isCustomFrameTypeOrOther(frame.getType())) {
     id = getId3libFrameIdForType(frame.getType());
   } else {
     id = getId3libFrameIdForName(frame.getName());
@@ -1771,6 +1901,9 @@ ID3_Frame* Mp3File::createId3FrameFromFrame(Frame& frame) const
           description = QLatin1String("GROUPING");
         } else if (frame.getType() == Frame::FT_Subtitle) {
           description = QLatin1String("SUBTITLE");
+        } else if (Frame::isCustomFrameType(frame.getType())) {
+          description = QString::fromLatin1(
+                Frame::getNameForCustomFrame(frame.getType()));
         } else {
           description = frame.getName();
         }
@@ -1854,6 +1987,9 @@ ID3_Frame* Mp3File::createId3FrameFromFrame(Frame& frame) const
     Frame::Type type;
     const char* name;
     getTypeStringForId3libFrameId(id, type, name);
+    if (type == Frame::FT_Other) {
+      type = Frame::getTypeFromCustomFrameName(QByteArray(id3Frame->GetTextID()));
+    }
     frame.setExtendedType(Frame::ExtendedType(type, QString::fromLatin1(name)));
   }
   return id3Frame;
@@ -1929,6 +2065,10 @@ Frame createFrameFromId3libFrame(ID3_Frame* id3Frame, int index)
   Frame::Type type;
   const char* name;
   getTypeStringForId3libFrameId(id3Frame->GetID(), type, name);
+  if (type == Frame::FT_Other) {
+    type = Frame::getTypeFromCustomFrameName(QByteArray(id3Frame->GetTextID()));
+  }
+
   Frame frame(type, QLatin1String(""), QString::fromLatin1(name), index);
   frame.setValue(getFieldsFromId3Frame(id3Frame, frame.fieldList()));
   if (id3Frame->GetID() == ID3FID_USERTEXT ||
@@ -1947,7 +2087,8 @@ Frame createFrameFromId3libFrame(ID3_Frame* id3Frame, int index)
         } else if (description == QLatin1String("SUBTITLE")) {
           frame.setType(Frame::FT_Subtitle);
         } else {
-          frame.setExtendedType(Frame::ExtendedType(Frame::FT_Other,
+          frame.setExtendedType(Frame::ExtendedType(
+              Frame::getTypeFromCustomFrameName(description.toLatin1()),
               frame.getInternalName() + QLatin1Char('\n') + description));
         }
       }
@@ -2166,8 +2307,11 @@ QStringList Mp3File::getFrameIds(Frame::TagNumber tagNr) const
 
   QStringList lst;
   for (int type = Frame::FT_FirstFrame; type <= Frame::FT_LastFrame; ++type) {
-    lst.append(Frame::ExtendedType(static_cast<Frame::Type>(type),
-                                   QLatin1String("")).getName());
+    auto name = Frame::ExtendedType(static_cast<Frame::Type>(type),
+                                    QLatin1String("")).getName();
+    if (!name.isEmpty()) {
+      lst.append(name);
+    }
   }
   for (int i = 0; i <= ID3FID_WWWUSER; ++i) {
     if (typeStrOfId[i].type == Frame::FT_Other) {
@@ -2181,13 +2325,20 @@ QStringList Mp3File::getFrameIds(Frame::TagNumber tagNr) const
 }
 
 /**
- * Set the text codec to be used for tag 1.
+ * Set the encoding to be used for tag 1.
  *
- * @param codec text codec, 0 to use default (ISO 8859-1)
+ * @param name of encoding, default is ISO 8859-1
  */
-void Mp3File::setTextCodecV1(const QTextCodec* codec)
+void Mp3File::setTextEncodingV1(const QString& name)
 {
-  s_textCodecV1 = codec;
+#if QT_VERSION >= 0x060000
+  auto encoding = QStringConverter::encodingForName(name.toLatin1());
+  s_decoderV1 = QStringDecoder(encoding.value_or(QStringConverter::Latin1));
+  s_encoderV1 = QStringEncoder(encoding.value_or(QStringConverter::Latin1));
+#else
+  s_textCodecV1 = name != QLatin1String("ISO-8859-1")
+      ? QTextCodec::codecForName(name.toLatin1().data()) : nullptr;
+#endif
 }
 
 /**
@@ -2208,11 +2359,7 @@ void Mp3File::setDefaultTextEncoding(TagConfig::TextEncoding textEnc)
  */
 void Mp3File::notifyConfigurationChange()
 {
-  const QTextCodec* id3v1TextCodec =
-    TagConfig::instance().textEncodingV1() != QLatin1String("ISO-8859-1") ?
-    QTextCodec::codecForName(
-          TagConfig::instance().textEncodingV1().toLatin1().data()) : nullptr;
   setDefaultTextEncoding(
     static_cast<TagConfig::TextEncoding>(TagConfig::instance().textEncoding()));
-  setTextCodecV1(id3v1TextCodec);
+  setTextEncodingV1(TagConfig::instance().textEncodingV1());
 }
