@@ -248,5 +248,5 @@ private:
 
   /** Metadata. */
   MetadataMap m_metadata;
-  QList<Frame> m_pictures;
+  QList<Frame> m_extraFrames;
 };
