@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Sep 2005
  *
- * Copyright (C) 2005-2007  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef MUSICBRAINZCONFIG_H
-#define MUSICBRAINZCONFIG_H
+#pragma once
 
 #include "serverimporterconfig.h"
 
@@ -42,7 +41,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~MusicBrainzConfig();
+  virtual ~MusicBrainzConfig() override;
 
 private:
   friend MusicBrainzConfig&
@@ -51,5 +50,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif // MUSICBRAINZCONFIG_H
