@@ -37,7 +37,7 @@
 #endif
 #include "pictureframe.h"
 #include "tagconfig.h"
-#include "fileproxymodel.h"
+#include "taggedfilesystemmodel.h"
 
 namespace {
 
@@ -140,7 +140,7 @@ long oggtell(void* stream)
 /**
  * Constructor.
  *
- * @param idx index in file proxy model
+ * @param idx index in tagged file system model
  */
 OggFile::OggFile(const QPersistentModelIndex& idx)
   : TaggedFile(idx), m_fileRead(false)
@@ -272,7 +272,7 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
               ::vorbis_comment_init(vc);
               auto it = m_comments.begin(); // clazy:exclude=detaching-member
               while (it != m_comments.end()) {
-                QString name((*it).getName());
+                QString name = fixUpTagKey(it->getName(), TT_Vorbis);
                 QString value((*it).getValue());
                 if (!value.isEmpty()) {
                   ::vorbis_comment_add_tag(
@@ -300,10 +300,11 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
         setFileTimeStamps(fnOut, actime, modtime);
       }
     }
-    const FileProxyModel* model = getFileProxyModel();
+    const TaggedFileSystemModel* model = getTaggedFileSystemModel();
     if (!writeOk) {
       // restore old file
-      if (!(model && model->remove(model->index(fnOut)))) {
+      if (!(model && const_cast<TaggedFileSystemModel*>(model)->remove(
+              model->index(fnOut)))) {
         QDir(dirname).remove(newFilename);
       }
       markFilenameUnchanged(); // currentFilename() will now return tempFilename
@@ -313,7 +314,8 @@ bool OggFile::writeTags(bool force, bool* renamed, bool preserve)
       return false;
     }
     markTagUnchanged(Frame::Tag_2);
-    if (!(model && model->remove(model->index(fnIn)))) {
+    if (!(model && const_cast<TaggedFileSystemModel*>(model)->remove(
+            model->index(fnIn)))) {
       QDir(dirname).remove(tempFilename);
     }
     setFilename(newFilename);
@@ -416,13 +418,16 @@ const char* getVorbisNameFromType(Frame::Type type)
     "RELEASEDATE",     // FT_ReleaseDate,
     "RATING",          // FT_Rating,
     "WORK"             // FT_Work,
-                       // FT_LastFrame = FT_Work
+                       // FT_Custom1
   };
-  Q_STATIC_ASSERT(sizeof(names) / sizeof(names[0]) == Frame::FT_LastFrame + 1);
+  Q_STATIC_ASSERT(sizeof(names) / sizeof(names[0]) == Frame::FT_Custom1);
   if (type == Frame::FT_Picture &&
       TagConfig::instance().pictureNameIndex() == TagConfig::VP_COVERART) {
     return "COVERART";
   }
+  if (Frame::isCustomFrameType(type)) {
+    return Frame::getNameForCustomFrame(type);
+  }
   return type <= Frame::FT_LastFrame ? names[type] : "UNKNOWN";
 }
 
@@ -438,7 +443,7 @@ Frame::Type getTypeFromVorbisName(QString name)
   static QMap<QString, int> strNumMap;
   if (strNumMap.empty()) {
     // first time initialization
-    for (int i = 0; i <= Frame::FT_LastFrame; ++i) {
+    for (int i = 0; i < Frame::FT_Custom1; ++i) {
       auto type = static_cast<Frame::Type>(i);
       strNumMap.insert(QString::fromLatin1(getVorbisNameFromType(type)), type);
     }
@@ -449,7 +454,7 @@ Frame::Type getTypeFromVorbisName(QString name)
   if (it != strNumMap.constEnd()) {
     return static_cast<Frame::Type>(*it);
   }
-  return Frame::FT_Other;
+  return Frame::getTypeFromCustomFrameName(name.toLatin1());
 }
 
 /**
@@ -852,8 +857,11 @@ QStringList OggFile::getFrameIds(Frame::TagNumber tagNr) const
   lst.reserve(Frame::FT_LastFrame - Frame::FT_FirstFrame + 1 +
               sizeof(fieldNames) / sizeof(fieldNames[0]));
   for (int k = Frame::FT_FirstFrame; k <= Frame::FT_LastFrame; ++k) {
-    lst.append(Frame::ExtendedType(static_cast<Frame::Type>(k),
-                                   QLatin1String("")).getName());
+    auto name = Frame::ExtendedType(static_cast<Frame::Type>(k),
+                                    QLatin1String("")).getName();
+    if (!name.isEmpty()) {
+      lst.append(name);
+    }
   }
   for (auto fieldName : fieldNames) {
     lst.append(QString::fromLatin1(fieldName));
