@@ -27,12 +27,12 @@
 #pragma once
 
 #include <QObject>
+#include <QQmlError>
 #include "iusercommandprocessor.h"
 
 class Kid3Application;
 class QQuickView;
 class QQmlEngine;
-class QQmlError;
 
 /**
  * Starter for QML scripts.
@@ -40,7 +40,7 @@ class QQmlError;
 class KID3_PLUGIN_EXPORT QmlCommandPlugin
     : public QObject, public IUserCommandProcessor {
   Q_OBJECT
-  Q_PLUGIN_METADATA(IID "net.sourceforge.kid3.IUserCommandProcessor")
+  Q_PLUGIN_METADATA(IID "org.kde.kid3.IUserCommandProcessor")
   Q_INTERFACES(IUserCommandProcessor)
 public:
   /**
@@ -99,6 +99,12 @@ signals:
    */
   void commandOutput(const QString& msg);
 
+  /**
+   * Emitted when the command finishes.
+   * @param exitCode exit code of command
+   */
+  void finished(int exitCode);
+
 private slots:
   void onEngineError(const QList<QQmlError>& errors);
   void onQmlViewClosing();
